@@ -30,6 +30,8 @@ import multiprocessing
 
 from paunch import runner as containers_runner
 
+PUPPETS = '/usr/share/openstack-puppet/modules/:/usr/share/openstack-puppet/modules/:ro'
+
 logger = None
 sh_script = '/var/lib/container-puppet/container-puppet.sh'
 container_cli = os.environ.get('CONTAINER_CLI', 'podman')
@@ -66,7 +68,7 @@ if not os.path.exists(config_volume_prefix):
     os.makedirs(config_volume_prefix)
 
 if container_cli == 'docker':
-    cli_dcmd = ['--volume', '/usr/share/openstack-puppet/modules/:/usr/share/openstack-puppet/modules/:ro']
+    cli_dcmd = ['--volume', PUPPETS]
     env = {}
     RUNNER = containers_runner.DockerRunner(
         'container-puppet', cont_cmd='docker', log=log)
@@ -74,7 +76,7 @@ elif container_cli == 'podman':
     # podman doesn't allow relabeling content in /usr and
     # doesn't support named volumes
     cli_dcmd = ['--security-opt', 'label=disable',
-                '--volume', '/usr/share/openstack-puppet/modules/:/usr/share/openstack-puppet/modules/:ro']
+                '--volume', PUPPETS]
     # podman need to find dependent binaries that are in environment
     env = {'PATH': os.environ['PATH']}
     RUNNER = containers_runner.PodmanRunner(
@@ -87,8 +89,9 @@ else:
 # NOTE: we require this to support the tarball extracted (Deployment archive)
 # puppet modules but our containers now also include puppet-tripleo so we
 # could use either
-if os.environ.get('MOUNT_HOST_PUPPET', 'true') == 'true':
-    cli_dcmd.extend(['--volume', '/usr/share/openstack-puppet/modules/:/usr/share/openstack-puppet/modules/:ro'])
+if (os.environ.get('MOUNT_HOST_PUPPET', 'true') == 'true' and
+   PUPPETS not in cli_dcmd):
+    cli_dcmd.extend(['--volume', PUPPETS])
 
 # this is to match what we do in deployed-server
 def short_hostname():
@@ -265,7 +268,8 @@ if not os.path.exists(sh_script):
     with open(sh_script, 'w') as script_file:
         os.chmod(script_file.name, 0o755)
         script_file.write("""#!/bin/bash
-        set -ex
+        set -e
+        [ "$DEBUG" = "false" ] || set -x
         mkdir -p /etc/puppet
         cp -dR /tmp/puppet-etc/* /etc/puppet
         rm -Rf /etc/puppet/ssl # not in use and causes permission errors
@@ -297,21 +301,27 @@ if not os.path.exists(sh_script):
         # $::deployment_type in puppet-tripleo
         export FACTER_deployment_type=containers
         export FACTER_uuid=$(cat /sys/class/dmi/id/product_uuid | tr '[:upper:]' '[:lower:]')
+        echo 'Running puppet'
+        # FIXME(bogdando): stdout may be falling behind of the logged syslog messages
+        set -x
         /usr/bin/puppet apply --summarize \
                 --detailed-exitcodes \
                 --color=false \
-                --logdest syslog \
-                --logdest console \
                 --modulepath=/etc/puppet/modules:/usr/share/openstack-puppet/modules \
                 $TAGS \
                 $CHECK_MODE \
-                /etc/config.pp
-        rc=$?
+                /etc/config.pp \
+                2>&1 | logger -s -t puppet-user
+        rc=${PIPESTATUS[0]}
+        [ "$DEBUG" = "false" ] && set +x
         set -e
         if [ $rc -ne 2 -a $rc -ne 0 ]; then
             exit $rc
         fi
 
+        verbosity=""
+        [ "$DEBUG" = "false" ] || verbosity="-v"
+
         # Disables archiving
         if [ -z "$NO_ARCHIVE" ]; then
             archivedirs=("/etc" "/root" "/opt" "/var/lib/ironic/tftpboot" "/var/lib/ironic/httpboot" "/var/www" "/var/spool/cron" "/var/lib/nova/.ssh")
@@ -337,16 +347,33 @@ if not os.path.exists(sh_script):
                     exclude_files+=" --exclude=$p"
                 fi
             done
-            rsync -a -R --delay-updates --delete-after $exclude_files $rsync_srcs /var/lib/config-data/${NAME}
+
+            # Exclude read-only mounted directories/files which we do not want
+            # to copy or delete.
+            ro_files="/etc/puppetlabs/ /opt/puppetlabs/"
+            for ro in $ro_files; do
+                if [ -e "$ro" ]; then
+                    exclude_files+=" --exclude=$ro"
+                fi
+            done
+
+            echo "Rsyncing config files from ${rsync_srcs} into /var/lib/config-data/${NAME}"
+            rsync -a $verbosity -R --delay-updates --delete-after $exclude_files $rsync_srcs /var/lib/config-data/${NAME}
 
 
             # Also make a copy of files modified during puppet run
             # This is useful for debugging
             echo "Gathering files modified after $(stat -c '%y' $origin_of_time)"
             mkdir -p /var/lib/config-data/puppet-generated/${NAME}
-            rsync -a -R -0 --delay-updates --delete-after $exclude_files \
-                          --files-from=<(find $rsync_srcs -newer $origin_of_time -not -path '/etc/puppet*' -print0) \
-                          / /var/lib/config-data/puppet-generated/${NAME}
+            exec 5>&1
+            exec 1>/tmp/files_from
+            find $rsync_srcs -newer $origin_of_time -not -path '/etc/puppet*' -print0
+            exec 1>&5
+            echo "Files modified during puppet run:"
+            cat /tmp/files_from | sort | xargs -0 printf "%s\n"
+            echo "Rsyncing the modified files into /var/lib/config-data/puppet-generated/${NAME}"
+            rsync -a $verbosity -R -0 --delay-updates --delete-after $exclude_files \
+                --files-from=/tmp/files_from / /var/lib/config-data/puppet-generated/${NAME}
 
             # Write a checksum of the config-data dir, this is used as a
             # salt to trigger container restart when the config changes
@@ -409,7 +436,7 @@ def mp_puppet_config(*args):
                 '--env', 'NO_ARCHIVE=%s' % os.environ.get('NO_ARCHIVE', ''),
                 '--env', 'STEP=%s' % os.environ.get('STEP', '6'),
                 '--env', 'NET_HOST=%s' % os.environ.get('NET_HOST', 'false'),
-                '--log-driver', 'json-file',
+                '--env', 'DEBUG=%s' % os.environ.get('DEBUG', 'false'),
                 '--volume', '/etc/localtime:/etc/localtime:ro',
                 '--volume', '%s:/etc/config.pp:ro' % tmp_man.name,
                 '--volume', '/etc/puppet/:/tmp/puppet-etc/:ro',
@@ -419,6 +446,9 @@ def mp_puppet_config(*args):
                 '--volume', '/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro',
                 '--volume', '/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro',
                 '--volume', '%s:/var/lib/config-data/:rw' % config_volume_prefix,
+                # facter caching
+                '--volume', '/var/lib/container-puppet/puppetlabs/facter.conf:/etc/puppetlabs/facter/facter.conf:ro',
+                '--volume', '/var/lib/container-puppet/puppetlabs/:/opt/puppetlabs/:ro',
                 # Syslog socket for puppet logs
                 '--volume', '/dev/log:/dev/log:rw']
         if privileged:
@@ -426,7 +456,8 @@ def mp_puppet_config(*args):
 
         if container_cli == 'podman':
             log_path = os.path.join(container_log_stdout_path, uname)
-            logging = ['--log-opt',
+            logging = ['--log-driver', 'k8s-file',
+                       '--log-opt',
                        'path=%s.log' % log_path]
             common_dcmd.extend(logging)
 
@@ -454,6 +485,9 @@ def mp_puppet_config(*args):
             log.debug('NET_HOST enabled')
             dcmd.extend(['--net', 'host', '--volume',
                          '/etc/hosts:/etc/hosts:ro'])
+        else:
+            log.debug('running without containers Networking')
+            dcmd.extend(['--net', 'none'])
 
         # script injection as the last mount to make sure it's accessible
         # https://github.com/containers/libpod/issues/1844
