@@ -299,6 +299,12 @@ def clean_templates(base_path, role_data_path, network_data_path):
             'network', '%s_from_pool_v6.yaml' % network['name_lower'])
         ports_path = os.path.join(
             'network', 'ports', '%s.yaml' % network['name_lower'])
+        external_resource_ports_path = os.path.join(
+            'network', 'ports',
+            'external_resource_%s.yaml' % network['name_lower'])
+        external_resource_ports_v6_path = os.path.join(
+            'network', 'ports',
+            'external_resource_%s_v6.yaml' % network['name_lower'])
         ports_from_pool_path = os.path.join(
             'network', 'ports', '%s_from_pool.yaml' % network['name_lower'])
         ports_v6_path = os.path.join(
@@ -311,6 +317,8 @@ def clean_templates(base_path, role_data_path, network_data_path):
         delete(network_v6_path)
         delete(network_from_pool_v6_path)
         delete(ports_path)
+        delete(external_resource_ports_path)
+        delete(external_resource_ports_v6_path)
         delete(ports_from_pool_path)
         delete(ports_v6_path)
         delete(ports_from_pool_v6_path)
@@ -324,9 +332,16 @@ def clean_templates(base_path, role_data_path, network_data_path):
         host_config_and_reboot_path = os.path.join(
             'extraconfig', 'pre_network',
             '%s-host_config_and_reboot.yaml' % role['name'].lower())
+        krb_service_principals_path = os.path.join(
+            'extraconfig', 'nova_metadata', 'krb-service-principals',
+            '%s-role.yaml' % role['name'].lower())
+        common_services_path = os.path.join(
+            'common', 'services', '%s-role.yaml' % role['name'].lower())
 
         delete(role_path)
         delete(host_config_and_reboot_path)
+        delete(krb_service_principals_path)
+        delete(common_services_path)
 
         nic_config_dir = os.path.join(base_path, 'network', 'config')
         for sample_nic_config_dir in os.listdir(nic_config_dir):
