@@ -148,8 +148,6 @@ PARAMETER_DEFINITION_EXCLUSIONS = {'CephPools': ['description',
                                    # There's one template that defines this
                                    # differently, and I'm not sure if we can
                                    # safely change it.
-                                   'EC2MetadataIp': ['default'],
-                                   # Same as EC2MetadataIp
                                    'ControlPlaneDefaultRoute': ['default'],
                                    # TODO(bnemec): Address these existing
                                    # inconsistencies.
@@ -195,15 +193,15 @@ PARAMETER_DEFINITION_EXCLUSIONS = {'CephPools': ['description',
                                    'image': ['description', 'default'],
                                    'NeutronBigswitchAgentEnabled': ['default'],
                                    'EndpointMap': ['description', 'default'],
-                                   'DockerManilaConfigImage': ['description',
-                                                               'default'],
+                                   'ContainerManilaConfigImage': ['description',
+                                                                  'default'],
                                    'replacement_policy': ['default'],
                                    'CloudDomain': ['description', 'default'],
                                    'EnableLoadBalancer': ['description'],
                                    'ControllerExtraConfig': ['description'],
                                    'NovaComputeExtraConfig': ['description'],
                                    'controllerExtraConfig': ['description'],
-                                   'DockerSwiftConfigImage': ['default'],
+                                   'ContainerSwiftConfigImage': ['default'],
                                    'input_values': ['default'],
                                    'fixed_ips': ['default', 'type']
                                    }
@@ -244,8 +242,6 @@ VALIDATE_DOCKER_OVERRIDE = {
 DEPLOYMENT_RESOURCE_TYPES = [
     'OS::Heat::SoftwareDeploymentGroup',
     'OS::Heat::StructuredDeploymentGroup',
-    'OS::Heat::StructuredDeployments',
-    'OS::Heat::SoftwareDeployments',
     'OS::Heat::SoftwareDeployment',
     'OS::Heat::StructuredDeployment',
     'OS::TripleO::SoftwareDeployment'
@@ -368,6 +364,7 @@ def validate_hci_role(hci_role_filename, hci_role_tpl):
         for role in hci_role_tpl:
             if role['name'] == 'HciCephAll':
                 hci_role_services = role['ServicesDefault']
+                hci_role_services.remove('OS::TripleO::Services::CephGrafana')
                 hci_role_services.remove('OS::TripleO::Services::CephMds')
                 hci_role_services.remove('OS::TripleO::Services::CephMgr')
                 hci_role_services.remove('OS::TripleO::Services::CephMon')
@@ -403,6 +400,7 @@ def validate_ceph_role(ceph_role_filename, ceph_role_tpl):
         for role in ceph_role_tpl:
             if role['name'] == 'CephAll':
                 ceph_role_services = role['ServicesDefault']
+                ceph_role_services.remove('OS::TripleO::Services::CephGrafana')
                 ceph_role_services.remove('OS::TripleO::Services::CephMds')
                 ceph_role_services.remove('OS::TripleO::Services::CephMgr')
                 ceph_role_services.remove('OS::TripleO::Services::CephMon')
@@ -433,6 +431,7 @@ def validate_controller_no_ceph_role(filename, tpl):
             services.remove('OS::TripleO::Services::CephClient')
             services.append('OS::TripleO::Services::CephMds')
             services.append('OS::TripleO::Services::CephMgr')
+            services.append('OS::TripleO::Services::CephGrafana')
             services.append('OS::TripleO::Services::CephMon')
             services.append('OS::TripleO::Services::CephRbdMirror')
             services.append('OS::TripleO::Services::CephRgw')
@@ -442,7 +441,7 @@ def validate_controller_no_ceph_role(filename, tpl):
                 return 1
     return 0
 
-def validate_with_compute_role_services(role_filename, role_tpl, exclude_service):
+def validate_with_compute_role_services(role_filename, role_tpl, exclude_service=()):
     cmpt_filename = os.path.join(os.path.dirname(role_filename),
                                  './Compute.yaml')
     cmpt_tpl = yaml.load(open(cmpt_filename).read())
@@ -456,8 +455,27 @@ def validate_with_compute_role_services(role_filename, role_tpl, exclude_service
               'ServicesDefault in roles/Compute.yaml'.format(role_filename,
               ', '.join(missing_services)))
         return 1
-    return 0
 
+    cmpt_us = cmpt_tpl[0].get('update_serial', None)
+    tpl_us = role_tpl[0].get('update_serial', None)
+
+    if 'OS::TripleO::Services::CephOSD' in role_services:
+        if tpl_us not in (None, 1):
+            print('ERROR: update_serial in {0} ({1}) '
+                  'is should be 1 as it includes CephOSD'.format(
+                      role_filename,
+                      tpl_us,
+                      cmpt_us))
+            return 1
+    elif cmpt_us is not None and tpl_us != cmpt_us:
+        print('ERROR: update_serial in {0} ({1}) '
+              'does not match roles/Compute.yaml {2}'.format(
+                  role_filename,
+                  tpl_us,
+                  cmpt_us))
+        return 1
+
+    return 0
 
 def validate_multiarch_compute_roles(role_filename, role_tpl):
     errors = 0
@@ -652,7 +670,7 @@ def validate_docker_service(filename, tpl):
                   return 1
 
             config_volume = puppet_config.get('config_volume')
-            expected_config_image_parameter = "Docker%sConfigImage" % to_camel_case(config_volume)
+            expected_config_image_parameter = "Container%sConfigImage" % to_camel_case(config_volume)
             if config_volume and not expected_config_image_parameter in tpl.get('parameters', []):
                 print('ERROR: Missing %s heat parameter for %s config_volume.'
                       % (expected_config_image_parameter, config_volume))
@@ -1069,13 +1087,15 @@ def validate(filename, param_map):
         if filename.startswith('./roles/'):
             retval = validate_role_name(filename)
 
-        if filename.startswith('./roles/ComputeHCI.yaml'):
+        if filename.startswith('./roles/ComputeHCI.yaml') or \
+                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
             retval |= validate_hci_computehci_role(filename, tpl)
 
         if filename.startswith('./roles/ComputeOvsDpdk.yaml') or \
                 filename.startswith('./roles/ComputeSriov.yaml') or \
                 filename.startswith('./roles/ComputeOvsDpdkRT.yaml') or \
-                filename.startswith('./roles/ComputeSriovRT.yaml'):
+                filename.startswith('./roles/ComputeSriovRT.yaml') or \
+                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
             exclude = [
                 'OS::TripleO::Services::OVNController',
                 'OS::TripleO::Services::ComputeNeutronOvsAgent',
@@ -1103,6 +1123,10 @@ def validate(filename, param_map):
         if filename == './roles/Compute.yaml':
             retval |= validate_multiarch_compute_roles(filename, tpl)
 
+        if filename in ('./roles/ComputeLocalEphemeral.yaml',
+                        './roles/ComputeRBDEphemeral.yaml'):
+            retval |= validate_with_compute_role_services(filename, tpl)
+
         # NOTE(hjensas): The routed network data example is very different ...
         # We need to develop a more advanced validator, probably using a schema
         # definition instead.
